cordova.define("com.playsyst.cordova.nativefile.nativefile", function(require, exports, module) {
var exec = require('cordova/exec');

exports.runProgram = function (success, error) {
    exec(success, error, 'NativeFile', 'runProgram',[]);
};

exports.startDevServer = function (path, success, error) {
    exec(success, error, 'NativeFile', 'startDevServer',[path]);
};

exports.stopDevServer = function (success, error) {
    exec(success, error, 'NativeFile', 'stopDevServer',[]);
};

/**
 * Sets the clipboard content
 *
 * @param {String}   text      The content to copy to the clipboard
 * @param {Function} onSuccess The function to call in case of success (takes the copied text as argument)
 * @param {Function} onFail    The function to call in case of error
 */
exports.copy = function (text, onSuccess, onFail) {
    if (typeof text === "undefined" || text === null) text = "";
	exec(onSuccess, onFail, "NativeFile", "copy", [text]);
};

/**
 * Gets the clipboard content
 *
 * @param {Function} onSuccess The function to call in case of success
 * @param {Function} onFail    The function to call in case of error
 */
exports.paste = function (onSuccess, onFail) {
	exec(onSuccess, onFail, "NativeFile", "paste", []);
};

/**
 * Clear the clipboard content
 *
 * @param {Function} onSuccess The function to call in case of success
 * @param {Function} onFail    The function to call in case of error
 */
exports.clear = function (onSuccess, onFail) {
	exec(onSuccess, onFail, "NativeFile", "clear", []);
};

exports.clipboard_hasResource = function (onSuccess, onFail) {
	exec(onSuccess, onFail, "NativeFile", "hasResource", []);
};

exports.startWatch = function (path, success, error) {
    exec(success, error, 'NativeFile', 'startWatch',[path]);
};

exports.stopWatch = function (key, success, error) {
    exec(success, error, 'NativeFile', 'stopWatch',[key]);
};

exports.clonedRemote = function (gitUrl, localPath, displayName, success, error) {
    exec(success, error, 'NativeFile', 'clonedRemote',[gitUrl, localPath, displayName]);
};

exports.cp_fork = function (cwd, modulePath, args, success, error) {
    exec(success, error, 'NativeFile', 'cp_fork',[cwd, modulePath, ...args]);
};

exports.cp_stdin_write = function (chunk, success, error) {
    exec(success, error, 'NativeFile', 'cp_stdin_write',[chunk]);
};

exports.cp_kill = function (success, error) {
    exec(success, error, 'NativeFile', 'cp_kill', []);
};

exports.cp_spawn = function (command, args, options, success, error) {
    exec(success, error, 'NativeFile', 'cp_spawn', [command, args, options]);
};

exports.cp_full_spawn = function (command, args, options, success, error) {
    exec(success, error, 'NativeFile', 'cp_full_spawn', [command, args, options]);
};

exports.cp_exec = function (command, success, error) {
    exec(success, error, 'NativeFile', 'cp_exec', [command]);
};

exports.stdin_write = function (pid, chunk, success, error) {
    exec(success, error, 'NativeFile', 'stdin_write', [pid, chunk]);
};

exports.kill = function (pid, success, error) {
    exec(success, error, 'NativeFile', 'kill', [pid]);
};

exports.pickFolder = function (defaultPath, success, error) {
    exec(success, error, 'NativeFile', 'pickFolder', [defaultPath]);
};

exports.openFolder = function (folder, success, error) {
    exec(success, error, 'NativeFile', 'openFolder', [folder]);
};

exports.showSaveDialog = function (options, success, error) {
    exec(success, error, 'NativeFile', 'showSaveDialog', [options]);
};

exports.newTerminal = function (folder, success, error) {
    exec(success, error, 'NativeFile', 'newTerminal', [folder]);
};

exports.showTerminal = function (success, error) {
    exec(success, error, 'NativeFile', 'showTerminal', []);
};

exports.db_get = function (db, sql, success, error) {
    exec(success, error, 'NativeFile', 'db_get', [db, sql]);
};

exports.db_all = function (db, sql, success, error) {
    exec(success, error, 'NativeFile', 'db_all', [db, sql]);
};

exports.db_exec = function (db, sql, success, error) {
    exec(success, error, 'NativeFile', 'db_exec', [db, sql]);
};

exports.db_updateItems = function (db, req, success, error) {
    exec(success, error, 'NativeFile', 'db_updateItems', [db, req]);
};

exports.lf_register = function (success, error) {
    exec(success, error, 'NativeFile', 'lf_register', []);
};

exports.lf_cancelShutdown = function (success, error) {
    exec(success, error, 'NativeFile', 'lf_cancelShutdown', []);
};

exports.lf_okShutdown = function (success, error) {
    exec(success, error, 'NativeFile', 'lf_okShutdown', []);
};

exports.lf_shutdown = function (success, error) {
    exec(success, error, 'NativeFile', 'lf_shutdown', []);
};

exports.pty_spawn = function (file, args, options, success, error) {
    exec(success, error, 'NativeFile', 'pty_spawn', [file, args, options]);
};

exports.pty_kill = function (pid, success, error) {
    exec(success, error, 'NativeFile', 'pty_kill', [pid]);
};

exports.pty_resize = function (pid, columns, rows, success, error) {
    exec(success, error, 'NativeFile', 'pty_resize', [pid, columns, rows]);
};

exports.pty_write = function (pid, data, success, error) {
    exec(success, error, 'NativeFile', 'pty_write', [pid, data]);
};

exports.key_initHooker = function (success, error) {
    exec(success, error, 'NativeFile', 'key_initHooker', []);
};

exports.url_open = function (url, success, error) {
    exec(success, error, 'NativeFile', 'url_open', [url]);
};

exports.readlink = function (path, success, error) {
    exec(success, error, 'NativeFile', 'readlink', [path]);
};

});
